@@ -12,7 +12,7 @@ __PACKAGE__->meta->make_immutable(inline_constructor => 0);
 
 =head1 NAME
 
-Reaction::Meta::InterfaceModel::Action::DomainModelAttribute
+Reaction::Meta::InterfaceModel::Object::DomainModelAttribute
 
 =head1 DESCRIPTION
 
