@@ -1,9 +1,10 @@
 package Reaction::UI::Controller::Root;
 
-use base qw/Reaction::UI::Controller/;
-use Reaction::Class;
+use Moose;
 use Reaction::UI::Window;
 
+BEGIN { extends 'Reaction::UI::Controller'; }
+
 __PACKAGE__->config(
   view_name => 'XHTML',
   content_type => 'text/html',
