@@ -6,14 +6,14 @@ use aliased 'Reaction::InterfaceModel::Collection';
 
 # XX This needs to be consumed after Ordered
 use namespace::clean -except => [ qw(meta) ];
-
+use MooseX::Types::Moose qw/Int/;
 
 #has paged_collection => (isa => Collection, is => 'rw', lazy_build => 1);
 
 has pager    => (isa => 'Data::Page', is => 'rw', lazy_build => 1);
-has page     => (isa => 'Int', is => 'rw', lazy_build => 1, trigger_adopt('page'), clearer => 'clear_page');
-has per_page => (isa => 'Int', is => 'rw', lazy_build => 1, trigger_adopt('page'));
-has per_page_max => (isa => 'Int', is => 'rw', lazy_build => 1);
+has page     => (isa => Int, is => 'rw', lazy_build => 1, trigger_adopt('page'), clearer => 'clear_page');
+has per_page => (isa => Int, is => 'rw', lazy_build => 1, trigger_adopt('page'));
+has per_page_max => (isa => Int, is => 'rw', lazy_build => 1);
 sub _build_page { 1  };
 sub _build_per_page { 10 };
 sub _build_per_page_max { 100 };
@@ -47,6 +47,6 @@ around _build_current_collection => sub {
   return $collection->where(undef, {rows => $self->per_page})->page($self->page);
 };
 
-
-
 1;
+
+__END__;
