@@ -5,10 +5,7 @@ use namespace::clean -except => [ qw(meta) ];
 extends 'Reaction::UI::ViewPort::Collection::Grid';
 
 with 'Reaction::UI::ViewPort::Collection::Role::Order';
-with 'Reaction::UI::ViewPort::Collection::Role::Pager';
-with 'Reaction::UI::ViewPort::Role::Actions';
 
 __PACKAGE__->meta->make_immutable;
 
-
 1;
