@@ -6,8 +6,6 @@ extends 'Reaction::UI::ViewPort::Collection::Grid';
 
 with 'Reaction::UI::ViewPort::Collection::Role::UseSearchSpec';
 with 'Reaction::UI::ViewPort::Collection::Role::Order';
-with 'Reaction::UI::ViewPort::Collection::Role::Pager';
-with 'Reaction::UI::ViewPort::Role::Actions';
 
 __PACKAGE__->meta->make_immutable;
 
