@@ -1,23 +1,21 @@
 package # hide from PAUSE
   RTest::TestDB::Foo;
 
-use base qw/DBIx::Class/;
-use metaclass 'Reaction::Meta::Class';
 use Moose;
+extends 'DBIx::Class';
 
 use MooseX::Types::Moose qw/ArrayRef Int/;
-use Reaction::Types::Core qw/NonEmptySimpleStr/;
+use MooseX::Types::Common::String qw/NonEmptySimpleStr/;
 
 has 'id' => (isa => Int, is => 'ro', required => 1);
 has 'first_name' => (isa => NonEmptySimpleStr, is => 'rw', required => 1);
 has 'last_name' => (isa => NonEmptySimpleStr, is => 'rw', required => 1);
-has 'bars' => (isa => ArrayRef );
-has 'bazes' =>
-  (
-   isa => ArrayRef,
-   required => 1,
-   reader => 'get_bazes',
-   writer => 'set_bazes'
+has 'bars' => (isa => ArrayRef, is => 'ro');
+has 'bazes' => (
+  isa => ArrayRef,
+  required => 1,
+  reader => 'get_bazes',
+  writer => 'set_bazes'
 );
 
 use namespace::clean -except => [ 'meta' ];
